@@ -13,13 +13,15 @@
 #'
 #' @export
 reset_custom_entity_patterns <- function() {
-  options(econid.custom_entity_patterns = tibble::tibble(
-    entity_id    = character(),
-    entity_name  = character(),
-    iso3c        = character(),
-    iso2c        = character(),
-    entity_type  = character(),
-    entity_regex = character()
-  ))
+  options(
+    econid.custom_entity_patterns = tibble::tibble(
+      entity_id = character(),
+      entity_name = character(),
+      iso3c = character(),
+      iso2c = character(),
+      entity_type = character(),
+      entity_regex = character()
+    )
+  )
   invisible(NULL)
 }
